==================
Text File To Audio
==================

.. image:: https://img.shields.io/pypi/v/text_to_mp3.svg
        :target: https://pypi.python.org/pypi/text_to_mp3

.. image:: https://travis-ci.org/shridarpatil/text-file-to-mp3.svg?branch=master
        :target: https://travis-ci.org/shridarpatil/text_file_to_audio

Converts a text file to mp3


* Free software: MIT license
* Documentation: https://text-file-to-mp3.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

